==> apache-camel-2.25.4-src.zip: apache-camel-2.25.4/components/camel-hazelcast/src/main/java/org/apache/camel/component/hazelcast/HazelcastUtil.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.hazelcast;

import com.hazelcast.config.Config;
import com.hazelcast.config.XmlConfigBuilder;
import com.hazelcast.core.Hazelcast;
import com.hazelcast.core.HazelcastInstance;

public final class HazelcastUtil {
    private HazelcastUtil() {
    }

    public static HazelcastInstance newInstance() {
        Config cfg = new XmlConfigBuilder().build();

        // hazelcast.version.check.enabled is deprecated
        cfg.setProperty(
            "hazelcast.phone.home.enabled",
            System.getProperty("hazelcast.phone.home.enabled", "false")
        );
        cfg.setProperty(
            "hazelcast.logging.type",
            System.getProperty("hazelcast.logging.type", "slf4j")
        );

        return newInstance(cfg);
    }

    public static HazelcastInstance newInstance(Config cfg) {
        return Hazelcast.newHazelcastInstance(cfg);
    }
}

==> apache-camel-4.15.0-src.zip: apache-camel-4.15.0/components/camel-hazelcast/src/main/java/org/apache/camel/component/hazelcast/HazelcastUtil.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.hazelcast;

import com.hazelcast.config.Config;
import com.hazelcast.config.XmlConfigBuilder;
import com.hazelcast.core.Hazelcast;
import com.hazelcast.core.HazelcastInstance;

public final class HazelcastUtil {
    private HazelcastUtil() {
    }

    public static HazelcastInstance newInstance() {
        Config cfg = new XmlConfigBuilder().build();

        // hazelcast.version.check.enabled is deprecated
        cfg.setProperty(
                "hazelcast.phone.home.enabled",
                System.getProperty("hazelcast.phone.home.enabled", "false"));
        cfg.setProperty(
                "hazelcast.logging.type",
                System.getProperty("hazelcast.logging.type", "slf4j"));

        return newInstance(cfg);
    }

    public static HazelcastInstance newInstance(Config cfg) {
        return Hazelcast.newHazelcastInstance(cfg);
    }
}
